@@ -1,11 +1,10 @@
 ; -*- Lisp -*-
 (in-package :maxima)
 
-(defparameter *autoconf-variables-set* "@variables_set@")
 (defparameter *autoconf-prefix* "/usr")
 (defparameter *autoconf-exec_prefix* "/usr")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.42.2")
+(defparameter *autoconf-version* "5.43.0")
 (defparameter *autoconf-libdir* "/usr/lib")
 (defparameter *autoconf-libexecdir* "/usr/lib")
 (defparameter *autoconf-datadir* "/usr/share")
@@ -19,7 +18,7 @@
 (defparameter *autoconf-ld-flags* "-Wl,-O1,--sort-common,--as-needed,-z,relro")
 
 ;; This will be T if this was a lisp-only build
-(defparameter *autoconf-lisp-only-build* (eq t '@lisp_only_build@))
+(defparameter *autoconf-lisp-only-build* (eq t 'nil))
  
-(defparameter *maxima-source-root* "/build/maxima-ecl/src/maxima-5.42.2")
+(defparameter *maxima-source-root* "/build/maxima-ecl/src/maxima-5.43.0")
 (defparameter *maxima-default-layout-autotools* "true")
